@@ -16,11 +16,11 @@ x <- read.swms2d.table(path)
 x$TPrint <- 20 * 60
 sd <- 0.3 ## then sd of log.gauss is 0.306878
 mu <- log(x$nCodeM[, 10]) - 0.5 * sd^2
-n <- 100 # better 10000
+n <- if (interactive()) 100 else 10 # better 10000
 front <- integer(n)
 
 for (j in 1:n) {
-  cat(j, "\n")
+  cat(j,"\n")
   x$nCodeM[, 10] <- rlnorm(length(x$nCodeM$z), m = mu, sd = sd)
   x$nCodeM[, 11] <- x$nCodeM[, 10]^(-2)
   z <- swms2d(x)$hQ[3, , ]
@@ -43,3 +43,4 @@ hist(distance, freq=FALSE,
 
 
 
+
